Notes - Nautobot Documentation

Skip to content

# Note

Added in version 1.4.0

Notes provide a place for you to store notes or general information on an object, such as a Device, that may not require a specific field for. This could be a note on a recent upgrade, a warning about a problematic device, or the reason the Rack was marked with the Status `Retired`.

The note field supports Markdown Basic Syntax as well as a limited subset of HTML.